################################################################
# upaCore
#
# (C) 2008 
# ZOPYX Limited & Co. KG
# Charlottenstr. 37/1, D-72070 Tübingen, Germany
# info@zopyx.com, www.zopyx.com 
################################################################

from Products.CMFCore.DirectoryView import registerDirectory
from Products.Archetypes.public import process_types, listTypes

from config import PROJECTNAME

registerDirectory('skins', globals())

def initialize(context):
    from content import memberinfo

    content_types, constructors, ftis = process_types(
        listTypes(PROJECTNAME),
        PROJECTNAME)

    # Assign an own permission to all content types
    # Heavily based on Bricolite's code from Ben Saller
    from permissions import permissions

    from Products.CMFCore.utils import ContentInit
    allTypes = zip(content_types, constructors)

    for atype, constructor in allTypes:
        kind = "%s: %s" % (PROJECTNAME, atype.archetype_name)
        ContentInit(
            kind,
            content_types      = (atype,),
            permission         = permissions[atype.portal_type],
            extra_constructors = (constructor,),
            fti                = ftis,
            ).initialize(context)



################################################################
# upaCore
#
# (C) 2008 
# ZOPYX Limited & Co. KG
# Charlottenstr. 37/1, D-72070 Tübingen, Germany
# info@zopyx.com, www.zopyx.com 
################################################################


from Globals import InitializeClass
from Products.Five import BrowserView
from Products.CMFCore.utils import getToolByName

class MiscView(BrowserView):
    """ helper code for managing the audience """

    def getFieldValue(self, fieldname):
        """ Return the value of a field for the current context object.
            Basically a convinience method for content types with
            an extended schema.
        """

        return self.context.getField(fieldname).getAccessor(self.context)()

    def setFieldValue(self, fieldname, value):
        """ Set the value of a field for the current context object.
            Basically a convinience method for content types with
            an extended schema.
        """

        return self.context.getField(fieldname).getMutator(self.context)(value)


InitializeClass(MiscView)



################################################################
# ubCore
#
# (C) 2008 
# ZOPYX Limited & Co. KG
# Charlottenstr. 37/1, D-72070 Tübingen, Germany
# info@zopyx.com, www.zopyx.com 
################################################################

import os, sys

if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from zope.component import getMultiAdapter
from AccessControl import Unauthorized
from Testing import ZopeTestCase
from Products.PloneTestCase.PloneTestCase import PloneTestCase, setupPloneSite, installProduct

installProduct('ubCore')
installProduct('LinguaPlone')
installProduct('Scrawl')
installProduct('Reflecto')
installProduct('ATVocabularyManager')
#installProduct('TextIndexNG3')

setupPloneSite(extension_profiles=('Products.ubCore:ubCore.default', ))

class TestInstallation(PloneTestCase):
    '''Test the various content types'''

    def afterSetUp(self):
        pass

    def testBlogEntry(self):
        self.login('gott')
        portal = self.portal
        # Standard blog entry can be created everywhere
        portal.invokeFactory('Blog Entry', 'blogentry')

        # now a blog folder
        portal.invokeFactory('BlogFolder', 'blog')
        blog = portal.blog
        blog.invokeFactory('Blog Entry', 'entry1')
        blog.invokeFactory('Blog Entry', 'entry2')
        blog.invokeFactory('Topic', 'aggregator')

        # this fails since we allow only Blog Entries
        self.assertRaises(ValueError, blog.invokeFactory, 'Page', 'page1')


    def testVocabularies(self):
        self.login('gott')
        ids = self.portal.portal_vocabularies.objectIds()
        self.assertEqual('audience' in ids, True)
        self.assertEqual('news_remote_servers' in ids, True)


    def testRelecto(self):
        self.login('gott')
        self.portal.invokeFactory('Reflector', 'reflector')


    def testAudience(self):
        self.login('gott')
        self.portal.invokeFactory('Document', 'doc')
        doc = self.portal.doc
        doc.getField('audience').getMutator(doc)(('alumni',))
        doc.view()


    def testAudienceManager(self):
        from Testing.makerequest import makerequest
        REQUEST = makerequest(self.app).REQUEST
    
        self.login('am')
        self.setRoles(('AudienceManager',))
        member = self.portal.portal_membership.getAuthenticatedMember()
        self.assertEqual('AudienceManager' in member.getRoles(), True)
        view = getMultiAdapter((self.portal, REQUEST), name='controlpanel-audience')
        result = view()

        self.logout()
        self.login('joe')
        member = self.portal.portal_membership.getAuthenticatedMember()
        view = getMultiAdapter((self.portal, REQUEST), name='controlpanel-audience')
        self.assertRaises(Unauthorized, view)



def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestInstallation))
    return suite

if __name__ == '__main__':
    framework()



# -*- coding: iso-8859-15 -*-

################################################################
# upaCore
#
# (C) 2008 
# ZOPYX Limited & Co. KG
# Charlottenstr. 37/1, D-72070 Tübingen, Germany
# info@zopyx.com, www.zopyx.com 
################################################################

from Products.CMFCore.permissions import setDefaultRoles

upacoreAddMemberInfo = 'upacore: Add MemberInfo'
upacoreViewInternally = 'upacore: View internally'

setDefaultRoles(upacoreAddMemberInfo, ('Manager', 'Member'))
setDefaultRoles(upacoreViewInternally, ('Manager', 'Member', 'Owner'))

# Maps portal_type to Add permissions

permissions = {
    'MemberInfo' : upacoreAddMemberInfo,
}





def gensite(self):

    sites = self.objectIds('Plone Site')
    id = 'ub-%d' % (len(sites) + 1)
    factory = self.manage_addProduct['CMFPlone']
    factory.addPloneSite(id, create_userfolder=True, extension_ids=('Products.ubCore:ubCore.default',))
    plone = self[id]
#    plone.setupMembers()
    self.REQUEST.RESPONSE.redirect(plone.absolute_url())



##########################################################################
# Products.upaCore
# (C) 2007, 2008, ZOPYX Ltd & Co. KG, Tuebingen, Germany
##########################################################################

import os
from setuptools import setup, find_packages


CLASSIFIERS = [
    'Programming Language :: Python',
    'Framework :: Zope2',
    'Framework :: Plone',
]

version =  '0.5.1.4'

readme_file= os.path.join('Products', 'upaCore', 'README.txt')
desc = open(readme_file).read().strip()
changes_file = os.path.join('docs', 'HISTORY.txt')
changes = open(changes_file).read().strip()

long_description = desc + '\n\nCHANGES\n=======\n\n' +  changes 

setup(name='Products.upaCore',
      version=version,
      license='GPL',
      author='Andreas Jung',
      author_email='info@zopyx.com',
      maintainer='Andreas Jung',
      maintainer_email='info@zopyx.com',
      classifiers=CLASSIFIERS,
      url='http://pypi.python.org/pypi/Products.upaCore',
      description='Member info implementation for the GermanUPA',
      long_description=long_description,
      packages=['Products', 'Products.upaCore'],
      include_package_data = True,
      zip_safe=False,
      install_requires=['setuptools', 'archetypes.schemaextender', 'Products.TrustedExecutables'],
      namespace_packages=['Products'],
      )



"""
CMFPlone setup handlers.
"""

import os

from Products.CMFCore.utils import getToolByName
from config import PROJECTNAME

class PloneGenerator:

    def installProducts(self, p):
        """QuickInstaller install of required Products"""
        qi = getToolByName(p, 'portal_quickinstaller')
        qi.installProduct('PloneFormGen')
        qi.installProduct('FCKeditor')
        qi.installProduct('Reflecto')

    def setupMembers(self, p):
        for method in (p.portal_membership.addMember, p.acl_users.userFolderEditUser):
            method('gott', 'gott', ('Member', 'Manager'), '')
            method('joe', 'joe', ('Member', ), '')


def importVarious(context):
    """ """

    if context.readDataFile('upacore_various.txt') is None:
        return

    site = context.getSite()
    gen = PloneGenerator()
    gen.installProducts(site)
    gen.setupMembers(site)
